package com.hungraim.ltc.controller;

import com.hungraim.ltc.redis.RedisCache;
import com.hungraim.ltc.util.CsoftSecurityUtil;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.security.oauth2.provider.endpoint.TokenEndpoint;
import org.springframework.security.web.authentication.logout.SecurityContextLogoutHandler;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.security.Principal;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 认证中心
 *
 * @author hubin
 */
@RestController
@RequestMapping("/oauth")
@AllArgsConstructor
public class AuthController {


  private final RedisCache redisCache;
  private final TokenEndpoint tokenEndpoint;

  @PostMapping("/token")
  @SneakyThrows
  public Result<OAuth2AccessToken> postAccessToken(Principal principal, @RequestParam Map<String, String> parameters)  {
    String password = parameters.get("password");
    String decrypt = CsoftSecurityUtil.decryptRSADefault(password);
    parameters.put("password", decrypt);
    OAuth2AccessToken oAuth2AccessToken = tokenEndpoint.postAccessToken(principal, parameters).getBody();

   // redisCache.setCacheObject("token", oAuth2AccessToken.getValue());
    return Result.success(oAuth2AccessToken);
  }

  /**
   * 获取公钥
   * @return
   */
  @GetMapping("/genKeyPair")
  public Result<String> genKeyPair() {
    Map keyMap = CsoftSecurityUtil.createKeyPairs();
    return Result.success(keyMap.get(0).toString());
  }

  @GetMapping("/logout")
  public Result doLogout(){
    return Result.success();
  }

}
